@@ -56,3 +56,7 @@ def auto_fix_config():
 	setdefault(config, 'server', 'auto')
 	setdefault(config, 'update_interval', 1800)
 	setdefault(config, 'filters', {'All': {'has': [], 'or': [], 'not': []}})
+	setdefault(config, 'archive_db_path', 'default')
+	setdefault(config, 'db_path_variable', 'DATABASE_URL')
+	setdefault(config, 'db_path', os.environ.get(config.db_path_variable, ''))
+	setdefault(config, 'data_format', 'pickle')
